#[derive(PartialEq, Debug)]
pub enum NodeType {
    Program,
    Identity,
    ObjectIdentifierIndex
}